# gov-sic

![Tests](https://github.com/ellsphillips/sic/actions/workflows/config.yml/badge.svg)

A lightweight library to parse and interface Standard Industrial Classification instances using the current UK SIC 2007 methodology.

`gov-sic` supports the UK SIC 2007 framework by unifying the classification of business establishments and other statistical units by their type of economic activity/engagement into a common structure.

## Data

Data used has been transformed using the [Office for National Statistics](https://www.ons.gov.uk/methodology/classificationsandstandards/ukstandardindustrialclassificationofeconomicactivities/uksic2007)' published opensource SIC structure and volume datasets.

## Installation

```bash
pip install -U pip setuptools wheel
pip install git+https://github.com/ellsphillips/sic
```
